# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# 内部错误。
INTERNALERROR = 'InternalError'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 参数取值错误。
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# AppId错误。
INVALIDPARAMETERVALUE_APPID = 'InvalidParameterValue.AppId'

# 数量错误。
INVALIDPARAMETERVALUE_COUNT = 'InvalidParameterValue.Count'

# 验证数据错误。
INVALIDPARAMETERVALUE_DATA = 'InvalidParameterValue.Data'

# 输入字符串为空。
INVALIDPARAMETERVALUE_EMPTYSTRING = 'InvalidParameterValue.EmptyString'

# 超过数量限制。
INVALIDPARAMETERVALUE_LIMIT = 'InvalidParameterValue.Limit'

# 订单编号错误。
INVALIDPARAMETERVALUE_ORDERID = 'InvalidParameterValue.OrderId'

# 超过数量限制。
INVALIDPARAMETERVALUE_OVERLIMIT = 'InvalidParameterValue.OverLimit'

# 无权限操作。
INVALIDPARAMETERVALUE_PERMISSIONDENIED = 'InvalidParameterValue.PermissionDenied'

# 数量错误。
INVALIDPARAMETERVALUE_QUANTITY = 'InvalidParameterValue.Quantity'

# TID编码错误。
INVALIDPARAMETERVALUE_TID = 'InvalidParameterValue.Tid'
